@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2007-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2007-2015 Horde LLC (http://www.horde.org/)
  *
  * @author   Chuck Hagenbuch <chuck@horde.org>
  * @license  http://www.horde.org/licenses/bsd BSD
@@ -25,6 +25,8 @@ class Horde_Http_Request_Factory
     {
         if (class_exists('HttpRequest', false)) {
             return new Horde_Http_Request_Peclhttp();
+        } elseif (class_exists('\http\Client', false)) {
+            return new Horde_Http_Request_Peclhttp2();
         } elseif (extension_loaded('curl')) {
             return new Horde_Http_Request_Curl();
         } elseif (ini_get('allow_url_fopen')) {
