@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2007-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2007-2015 Horde LLC (http://www.horde.org/)
  *
  * Resources:
  * http://wezfurlong.org/blog/2006/nov/http-post-from-php-without-curl
@@ -49,7 +49,7 @@ class Horde_Http_Request_Fopen extends Horde_Http_Request_Base
     public function send()
     {
         $method = $this->method;
-        $uri = $this->uri;
+        $uri = (string)$this->uri;
         $headers = $this->headers;
         $data = $this->data;
         if (is_array($data)) {
