@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2007-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2007-2015 Horde LLC (http://www.horde.org/)
  *
  * @author   Chuck Hagenbuch <chuck@horde.org>
  * @license  http://www.horde.org/licenses/bsd BSD
@@ -17,7 +17,9 @@
 class Horde_Http_Request_Peclhttp extends Horde_Http_Request_PeclhttpBase
 {
     /**
-     * Map of HTTP authentication schemes from Horde_Http constants to HTTP_AUTH constants.
+     * Map of HTTP authentication schemes from Horde_Http constants to
+     * HTTP_AUTH constants.
+     *
      * @var array
      */
     protected $_httpAuthSchemes = array(
@@ -54,7 +56,7 @@ class Horde_Http_Request_Peclhttp extends Horde_Http_Request_PeclhttpBase
             throw new Horde_Http_Exception('Method ' . $this->method . ' not supported.');
         }
 
-        $httpRequest = new HttpRequest($this->uri, constant('HTTP_METH_' . $this->method));
+        $httpRequest = new HttpRequest((string)$this->uri, constant('HTTP_METH_' . $this->method));
 
         $data = $this->data;
         if (is_array($data)) {
@@ -79,6 +81,6 @@ class Horde_Http_Request_Peclhttp extends Horde_Http_Request_PeclhttpBase
             }
         }
 
-        return new Horde_Http_Response_Peclhttp($this->uri, $httpResponse);
+        return new Horde_Http_Response_Peclhttp((string)$this->uri, $httpResponse);
     }
 }
