@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2007-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2007-2015 Horde LLC (http://www.horde.org/)
  *
  * @author   Chuck Hagenbuch <chuck@horde.org>
  * @license  http://www.horde.org/licenses/bsd BSD
@@ -42,9 +42,10 @@ class Horde_Http_Response_Peclhttp extends Horde_Http_Response_Base
         $this->httpVersion = $message->getHttpVersion();
         $this->code = $message->getResponseCode();
         $this->_message = $message;
-        foreach ($message->getHeaders() as $k => $v) {
-            $this->headers[strtolower($k)] = $v;
-        }
+        $this->_headers = new Horde_Support_CaseInsensitiveArray(
+            $message->getHeaders()
+        );
+        $this->headers = array_change_key_case($this->_headers->getArrayCopy());
     }
 
     public function getBody()
