@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2007-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2007-2015 Horde LLC (http://www.horde.org/)
  *
  * @author   Michael Cramer <michael@bigmichi1.de>
  * @license  http://www.horde.org/licenses/bsd BSD
@@ -32,19 +32,23 @@ class Horde_Http_Response_Peclhttp2 extends Horde_Http_Response_Base
     public function __construct($uri, \http\Client\Response $response)
     {
         try {
-            $parent = $response->getParentMessage();
-            $location = $parent->getHeader('Location');
-            $this->uri = $location;
-        } catch (HttpRuntimeException $e) {
+            $info = $response->getTransferInfo();
+        } catch (\http\Exception $e) {
+            throw new Horde_Http_Exception($e);
+        }
+        try {
+            $this->uri = $info->effective_url;
+        } catch (\http\Exception\RuntimeException $e) {
             $this->uri = $uri;
         }
 
         $this->httpVersion = $response->getHttpVersion();
-        $this->code = $response->getResponseCode();
+        $this->code = $info->response_code;
         $this->_response = $response;
-        foreach ($response->getHeaders() as $k => $v) {
-            $this->headers[strtolower($k)] = $v;
-        }
+        $this->_headers = new Horde_Support_CaseInsensitiveArray(
+            $response->getHeaders()
+        );
+        $this->headers = array_change_key_case($this->_headers->getArrayCopy());
     }
 
     public function getBody()
